/* Time-stamp: <2006-06-11 13:57:01 jcs>
|
|  Copyright (C) 2002-2005 Jorg Schuler <jcsjcs at users sourceforge net>
|  Part of the gtkpod project.
| 
|  URL: http://www.gtkpod.org/
|  URL: http://gtkpod.sourceforge.net/
|
|  This program is free software; you can redistribute it and/or modify
|  it under the terms of the GNU General Public License as published by
|  the Free Software Foundation; either version 2 of the License, or
|  (at your option) any later version.
|
|  This program is distributed in the hope that it will be useful,
|  but WITHOUT ANY WARRANTY; without even the implied warranty of
|  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
|  GNU General Public License for more details.
|
|  You should have received a copy of the GNU General Public License
|  along with this program; if not, write to the Free Software
|  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
|
|  iTunes and iPod are trademarks of Apple
|
|  This product is not supported/written/published by Apple!
|
|  $Id: mp3file.h,v 1.24 2006/06/11 16:04:51 jcsjcs Exp $
*/

#ifndef MP3FILEH_INCLUDED
#define MP3FILEH_INCLUDED 1

#include "itdb.h"

gboolean mp3_write_file_info (gchar *filename, Track *track);
Track *mp3_get_file_info (gchar *name);
gboolean mp3_read_soundcheck (gchar *path, Track *track);

#endif
